/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hadoop.hive.llap;

import java.io.DataInput;
import java.io.DataOutput;
import java.io.IOException;
import org.apache.hadoop.io.Writable;

public class FieldDesc implements Writable {
  private String name;
  private TypeDesc typeDesc;

  public FieldDesc() {
    typeDesc = new TypeDesc();
  }

  public FieldDesc(String name, TypeDesc typeDesc) {
    this.name = name;
    this.typeDesc = typeDesc;
  }

  public String getName() {
    return name;
  }

  public TypeDesc getTypeDesc() {
    return typeDesc;
  }

  @Override
  public String toString() {
    return getName() + ":" + getTypeDesc().toString();
  }

  @Override
  public void write(DataOutput out) throws IOException {
    out.writeUTF(name);
    typeDesc.write(out);
  }

  @Override
  public void readFields(DataInput in) throws IOException {
    name = in.readUTF();
    typeDesc.readFields(in);
  }
}